@@ -1,6 +1,6 @@
 """Hanzo - Complete AI Infrastructure Platform with CLI, Router, MCP, and Agent Runtime."""
 
-__version__ = "0.2.10"
+__version__ = "0.3.2"
 __all__ = ["main", "cli"]
 
-from .cli import main, cli
\ No newline at end of file
+from .cli import cli, main
