@@ -144,7 +144,7 @@ async def run(ctx, tool: str, arg: tuple, json_args: str):
             # Try to parse value as JSON first
             try:
                 args[key] = json.loads(value)
-            except:
+            except Exception:
                 args[key] = value
 
     # Create server and run tool
@@ -189,7 +189,7 @@ async def run(ctx, tool: str, arg: tuple, json_args: str):
             # Try to parse as JSON for pretty printing
             data = json.loads(result)
             console.print_json(data=data)
-        except:
+        except Exception:
             # Display as text
             console.print(result)
     else:
@@ -207,7 +207,7 @@ async def run(ctx, tool: str, arg: tuple, json_args: str):
 def install(ctx, path: str):
     """Install MCP server in Claude Desktop."""
     try:
-        from hanzoai.mcp import create_server
+        import hanzoai.mcp
     except ImportError:
         console.print("[red]Error:[/red] hanzo-mcp not installed")
         console.print("Install with: pip install hanzo[mcp]")
